window.Gleam.initSearch([{"doc":"chip","title":"chip","content":"# chip\n\n[![Package Version](https://img.shields.io/hexpm/v/chip)](https://hex.pm/packages/chip)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/chip/)\n\nA pure gleam process registry that plays along types and gleam OTP abstractions.\nWill automatically delist dead processes. \n\n### Example\n\n```gleam\nimport gleam/erlang/process\nimport chip\n\n// Names can be built out of any primitive or even types.\ntype Name {\n  A\n  B\n}\n\n// We can start the registry and register a new subject \nlet assert Ok(registry) = chip.start()\nchip.register(registry, A, process.new_subject())\n\n// If we lose scope of our processes, just look it up in the registry!\nlet assert Ok(subject) = chip.find(registry, A)\nlet assert Error(chip.NotFound) = chip.find(registry, B)\n```\n\nFeature-wise its still very basic but planning to integrate: \n\n* `via` helper to initialize processes through the registry\n* Being able to manage process groups.\n* Dynamic dispatch helpers for pub-sub behaviour.\n\nOther features which are out of scope at this stage: \n\n* Match-spec lookup.\n* Multi-node distribution.\n* General performance (ets, partitions, multi-process dispatch, efficient lookups).\n\n## Installation\n\nYou can If available on Hex this package can be added to your Gleam project:\n\n```sh\ngleam add chip\n```\n\nand its documentation can be found at &lt;https://hexdocs.pm/chip&gt;.\n","url":"index.html"},{"doc":"chip","title":"Action","content":"pub opaque type Action(name, message)\n\n\nSynonyms:\nchip.Action\nchip Action","url":"chip.html#Action"},{"doc":"chip","title":"all","content":"pub fn all(registry: Subject(Action(a, b))) -&gt; List(Subject(b))\n\nSynonyms:\nchip.all\nchip all","url":"chip.html#all"},{"doc":"chip","title":"deregister","content":"pub fn deregister(registry: Subject(Action(a, b)), name: a) -&gt; Nil\n\nSynonyms:\nchip.deregister\nchip deregister","url":"chip.html#deregister"},{"doc":"chip","title":"lookup","content":"pub fn lookup(registry: Subject(Action(a, b)), name: a) -&gt; List(\n  Subject(b),\n)\n\nSynonyms:\nchip.lookup\nchip lookup","url":"chip.html#lookup"},{"doc":"chip","title":"register","content":"pub fn register(registry: Subject(Action(a, b)), start: fn() -&gt;\n    Result(Subject(b), StartError)) -&gt; Result(\n  Subject(b),\n  StartError,\n)\n\nSynonyms:\nchip.register\nchip register","url":"chip.html#register"},{"doc":"chip","title":"register_as","content":"pub fn register_as(registry: Subject(Action(a, b)), name: a, start: fn() -&gt;\n    Result(Subject(b), StartError)) -&gt; Result(\n  Subject(b),\n  StartError,\n)\n\nSynonyms:\nchip.register_as\nchip register_as","url":"chip.html#register_as"},{"doc":"chip","title":"start","content":"pub fn start() -&gt; Result(Subject(Action(a, b)), StartError)\n\nSynonyms:\nchip.start\nchip start","url":"chip.html#start"},{"doc":"chip","title":"stop","content":"pub fn stop(registry: Subject(Action(a, b))) -&gt; ExitReason\n\nSynonyms:\nchip.stop\nchip stop","url":"chip.html#stop"},{"doc":"chip","title":"chip","content":"","url":"chip.html"}]);